Labelflair

Struct Labelflair 

pub struct Labelflair {}
Generate a colorful palette of labels for your GitHub Issues

This struct provides the high-level interface to convert a configuration into a list of labels for GitHub Issues. Its generate method takes a configuration and expands it into a list of labels that can be serialized for use with GitHub’s API.

Implementations

Source

impl Labelflair

pub fn generate(config: &ConfigV1) -> Vec<Label>

Generate a list of GitHub Issues labels from the configuration

This function takes a configuration and generates a list of labels based on the groups defined in the configuration.

Given this configuration:

[[group]]
prefix = "C-"
colors = { tailwind = "red" }
labels = ["bug", "feature"]

It will generate the following labels:

- name: C-bug
  color: '#fca5a5'
- name: C-feature
  color: '#b91c1c'